==> zio-aws-wafregional_3-5.17.112.1-sources.jar: zio/aws/wafregional/model/CreateGeoMatchSetResponse.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.ChangeToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateGeoMatchSetResponse(
    geoMatchSet: Option[zio.aws.wafregional.model.GeoMatchSet] = None,
    changeToken: Option[ChangeToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.CreateGeoMatchSetResponse = {
    import CreateGeoMatchSetResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.CreateGeoMatchSetResponse
      .builder()
      .optionallyWith(geoMatchSet.map(value => value.buildAwsValue()))(
        _.geoMatchSet
      )
      .optionallyWith(
        changeToken.map(value => ChangeToken.unwrap(value): java.lang.String)
      )(_.changeToken)
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.CreateGeoMatchSetResponse.ReadOnly =
    zio.aws.wafregional.model.CreateGeoMatchSetResponse.wrap(buildAwsValue())
}
object CreateGeoMatchSetResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.CreateGeoMatchSetResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.CreateGeoMatchSetResponse =
      zio.aws.wafregional.model.CreateGeoMatchSetResponse(
        geoMatchSet.map(value => value.asEditable),
        changeToken.map(value => value)
      )
    def geoMatchSet: Option[zio.aws.wafregional.model.GeoMatchSet.ReadOnly]
    def changeToken: Option[ChangeToken]
    def getGeoMatchSet
        : ZIO[Any, AwsError, zio.aws.wafregional.model.GeoMatchSet.ReadOnly] =
      AwsError.unwrapOptionField("geoMatchSet", geoMatchSet)
    def getChangeToken: ZIO[Any, AwsError, ChangeToken] =
      AwsError.unwrapOptionField("changeToken", changeToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.CreateGeoMatchSetResponse
  ) extends zio.aws.wafregional.model.CreateGeoMatchSetResponse.ReadOnly {
    override val geoMatchSet
        : Option[zio.aws.wafregional.model.GeoMatchSet.ReadOnly] = scala
      .Option(impl.geoMatchSet())
      .map(value => zio.aws.wafregional.model.GeoMatchSet.wrap(value))
    override val changeToken: Option[ChangeToken] = scala
      .Option(impl.changeToken())
      .map(value => zio.aws.wafregional.model.primitives.ChangeToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.CreateGeoMatchSetResponse
  ): zio.aws.wafregional.model.CreateGeoMatchSetResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-wafregional_3-5.17.295.22-sources.jar: zio/aws/wafregional/model/CreateGeoMatchSetResponse.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.ChangeToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateGeoMatchSetResponse(
    geoMatchSet: Optional[zio.aws.wafregional.model.GeoMatchSet] =
      Optional.Absent,
    changeToken: Optional[ChangeToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.CreateGeoMatchSetResponse = {
    import CreateGeoMatchSetResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.CreateGeoMatchSetResponse
      .builder()
      .optionallyWith(geoMatchSet.map(value => value.buildAwsValue()))(
        _.geoMatchSet
      )
      .optionallyWith(
        changeToken.map(value => ChangeToken.unwrap(value): java.lang.String)
      )(_.changeToken)
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.CreateGeoMatchSetResponse.ReadOnly =
    zio.aws.wafregional.model.CreateGeoMatchSetResponse.wrap(buildAwsValue())
}
object CreateGeoMatchSetResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.CreateGeoMatchSetResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.CreateGeoMatchSetResponse =
      zio.aws.wafregional.model.CreateGeoMatchSetResponse(
        geoMatchSet.map(value => value.asEditable),
        changeToken.map(value => value)
      )
    def geoMatchSet: Optional[zio.aws.wafregional.model.GeoMatchSet.ReadOnly]
    def changeToken: Optional[ChangeToken]
    def getGeoMatchSet
        : ZIO[Any, AwsError, zio.aws.wafregional.model.GeoMatchSet.ReadOnly] =
      AwsError.unwrapOptionField("geoMatchSet", geoMatchSet)
    def getChangeToken: ZIO[Any, AwsError, ChangeToken] =
      AwsError.unwrapOptionField("changeToken", changeToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.CreateGeoMatchSetResponse
  ) extends zio.aws.wafregional.model.CreateGeoMatchSetResponse.ReadOnly {
    override val geoMatchSet
        : Optional[zio.aws.wafregional.model.GeoMatchSet.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.geoMatchSet())
        .map(value => zio.aws.wafregional.model.GeoMatchSet.wrap(value))
    override val changeToken: Optional[ChangeToken] = zio.aws.core.internal
      .optionalFromNullable(impl.changeToken())
      .map(value => zio.aws.wafregional.model.primitives.ChangeToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.CreateGeoMatchSetResponse
  ): zio.aws.wafregional.model.CreateGeoMatchSetResponse.ReadOnly = new Wrapper(
    impl
  )
}
